@@ -1,4 +1,4 @@
-/* @(#) $Id: actsync.c,v 1.40 2003/01/19 01:15:25 rra Exp $ */
+/* @(#) $Id: actsync.c,v 1.40.2.1 2003/05/31 19:48:25 rra Exp $ */
 /* @(#) Under RCS control in /usr/local/news/src/inn/local/RCS/actsync.c,v */
 /*
  * actsync - sync or merge two active files
@@ -2627,13 +2627,13 @@ exec_cmd(mode, cmd, grp, type, who)
 	p = concatpath(innconf->pathbin, _PATH_CTLINND);
 	if (type == NULL) {
 	    execl(p,
-		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, NULL);
+		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, (char *) 0);
 	} else if (who == NULL) {
 	    execl(p,
-		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, type, NULL);
+		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, type, (char *) 0);
 	} else {
 	    execl(p,
-		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, type, who, NULL);
+		  CTLINND_NAME, CTLINND_TIME_OUT, cmd, grp, type, who, (char *) 0);
 	}
 
 	/* child exec failed */
