@@ -1,4 +1,4 @@
-/*  $Id: main.c,v 1.47 2003/01/19 19:58:22 rra Exp $
+/*  $Id: main.c,v 1.47.2.1 2003/05/31 19:48:26 rra Exp $
 **
 **  Main routines for the innfeed program.
 **
@@ -392,7 +392,7 @@ int main (int argc, char **argv)
           close (2) ;
           dup2 (fds[1],1) ;
           dup2 (fds[1],2) ;
-          execlp ("sh","sh", "-c", subProgram, NULL) ;
+          execlp ("sh", "sh", "-c", subProgram, (char *) 0) ;
           perror ("execlp") ;
           exit (1) ;
         }
